/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

/*******************************************************************************
 * Create (job management) run schedule
 */
var fn = function(_view){
	var __ = cm
	,_pers = this
	;
	
	var view = $.extend({}, __._fnview_grid_grid, {
		base_date   : null
		,schedule_id: ""
		,jobunit_id : ""
		,load_flg : false
		,/*
		 * Set caption of grid
		 */
		setCaption: function(){
			var _ = this;
			
			_.lgrid.setCaption([
				__.getLang("schedule_id"), ": " , _.schedule_id
			].join(""));
		}
		
		,/*
		 * Set specified period
		 */
		setSpecifiedPeriod: function(){
			var _       = this
			,period_bar = _.rgrid.$pgr.find("td:last")
			,$div = period_bar.find("div:first")
			;
			
			if($div.length == 0){
				$div = $("<div class='container-period'></div>");
				$div.appendTo(period_bar);
			}
			
			if(period_bar.length){
				var str_date = $.fn.fmatter
						.hnmDatetime(_.base_date, __.getLang("period_format"));
				
				$div.html(
					__.getLang("specified_period").replace(/\{0\}/, str_date)
				);
			}
		}
		,/*
		 * Call load data when click on view 'history' content
		 */
		updateData: function(){
			var _ = this;
		
			if (!(_.load_flg)) {
				_.load_flg = true;
				_.reloadGrid();
				
			}
			
		}
		
		,/*
		 * Load data when click on view 'history' content
		 */
		reloadGrid: function(){
			var _        = this 
			,schedule_id = _view.__schedule_id
			,jobunit_id  = _view.__jobunit_id
			,lgrid       = _.lgrid
			,rgrid       = _.rgrid
			;
			
			// Check for update data
			if((schedule_id == _.schedule_id)
				&& (jobunit_id == _.jobunit_id)){
				_.load_flg = false;
				return;
			}


			// Get new value of schedule_id and job_id
			_.schedule_id = schedule_id;
			_.jobunit_id  = jobunit_id;
			
			// Renew caption
			_.refreshGrids();
			_.setCaption();
		}
		
		,/*
		 * Construct for grids
		 */
		createGrids: function(){
			var _     = this
			,datefull = new Date() // getToday
			;
			
			// Set base_date: Only get long value of date
			_.base_date = (
				new Date()
			).getTime();
			
			// Check schedule_id of view: control
			if(_view.__schedule_id){
				_.schedule_id = _view.__schedule_id;
			}
			
			// Check jobunit_id of view: control
			if(_view.__jobunit_id){
				_.jobunit_id = _view.__jobunit_id;
			}
			
			// Get header of grid
			$.ajax({
				url      : "get_run_schedule_detail_table_defines"
				,dataType: "json"
				,type    : "post"
				,data    : {base: _.base_date}
				,success : function(data_respond, textStatus, jqXHR){
					var headers
					,lgrid = _.lgrid
					,lpgr  = lgrid.$pgr
					,rgrid = _.rgrid
					,rpgr  = rgrid.$pgr
					;
					
					// Check validation of default json data_respond
					if (__.checkJsonError(data_respond) !== true){
						return;
					}
					
					// Check validation of content json data_respond
					if(!((headers = data_respond.headers) && $.isArray(headers)
						&& (headers.length == 2))){
						__.loadDataError(jqXHR, textStatus);
						return;
					}
					
					// Set some options for left grid
					var left_header = headers[0];
					$.extend(left_header, {
						pager          : lpgr
						,treeGrid      : true
						,treeGridModel : "adjacency"
						,ExpandColumn  : "tree"
						,datatype      : "jsonstring"
						,treedatatype  : "local"
						,treeIcons     : {
							plus  :"ui-icon-hnm-plus"
							,minus:"ui-icon-hnm-minus"
							,leaf :"ui-icon-hnm-none"
						} 
						,scrollCallback: function(){
							var f_grid = _.rgrid
							,scr_top   = this.bDiv.scrollTop
							;
							
							if(f_grid){
								if(scr_top === undefined){
									scr_top = 0;
								}
								f_grid.closest("div.ui-jqgrid-bdiv").scrollTop(scr_top);
							}
						}
						,jsonReader    : {
							repeatitems: false,
							root       : function (obj) { return obj; },
							page       : function (obj) { return 1; },
							total      : function (obj) { return 1; },
							records    : function (obj) { return obj.length; }
						}
					});
					
					lgrid.processData(left_header);
					lgrid.controlSize();
					
					// Set some options for right grid
					var right_header = headers[1];
					$.extend(right_header, {
						pager          : rpgr
						,caption       : "&nbsp;"
						,treeGrid      : true
						,treeGridModel : "adjacency"
						,ExpandColumn  : "tree"
						,datatype      : "jsonstring"
						,treedatatype  : "local"
						,treeIcons     : {
							plus  :"ui-icon-hnm-plus"
							,minus:"ui-icon-hnm-minus"
							,leaf :"ui-icon-hnm-none"
						} 
						,scrollCallback: function(){
							var f_grid = _.lgrid
							,scr_top   = this.bDiv.scrollTop
							;
							
							if(f_grid){
								if(scr_top === undefined){
									scr_top = 0;
								}
								f_grid.closest("div.ui-jqgrid-bdiv").scrollTop(scr_top);
							}
						}
						,jsonReader    : {
							repeatitems: true,
							root       : function (obj) { return obj; },
							page       : function (obj) { return 1; },
							total      : function (obj) { return 1; },
							records    : function (obj) { return obj.length; }
						}
					});
					
					rgrid.processData(right_header);
					rgrid.controlSize();
					
					// Call function processing data for grid
					_.refreshGrids();
					_.setCaption();
					_.setSpecifiedPeriod();
					
				}
				,error   : __.loadDataError
			});
		}
		
		,/*
		 * Construct for grids
		 */
		refreshGrids: function(update){
			var _        = this
			,lgrid       = _.lgrid
			,rgrid       = _.rgrid
			,ldate       = _.base_date
			,schedule_id = _.schedule_id
			,jobunit_id  = _.jobunit_id
			,check_value
			;
			
			// Format boolean type for update
			if(update !== true){
				update = false;
			}
			
			// Clear grids data
			lgrid.clearGridData();
			rgrid.clearGridData();
			
			// Check whether schedule_id or jobunit_id is empty
			if(!(schedule_id && jobunit_id)){
				return;
			}
			
			// Get data of grids
			$.ajax({
				url      : "get_run_schedule_detail_data"
				,dataType: "json"
				,type    : "post"
				,data    : {
					updateHeader: update
					,base       : ldate
					,scheduleId : schedule_id
					,jobunitId  : jobunit_id
				}
				,success : function(data_respond, textStatus, jqXHR){
					var left_data
					,right_data
					,col_names
					,lgrid = _.lgrid
					,rgrid = _.rgrid
					,len
					;
					
					if ((check_value = cm.checkJsonError(data_respond))
						=== false){
						return;
					}
						
					// Check check_value
					if(check_value === true){
						// Check validation of data
						if(!((left_data = data_respond.leftData)
							&& (right_data = data_respond.rightData))){
							__.loadDataError(jqXHR, textStatus);
							return;
						}
						
						// Add left data of grid
						len = left_data.length;
						for(var lcnt = 0; lcnt < len; lcnt++){
							var row_data = left_data[lcnt];
							// Check validation
							if(row_data.hasOwnProperty("nodeid")
									&& row_data.hasOwnProperty("parentid")
									&& row_data.hasOwnProperty("data")){
								lgrid.addChildNode(
									row_data.nodeid
									,row_data.parentid
									,row_data.data
								)
							}
						}
						
						// Add right data of grid
						len = right_data.length;
						for(var lcnt = 0; lcnt < len; lcnt++){
							var row_data = right_data[lcnt];
							// Check validation
							if(row_data.hasOwnProperty("nodeid")
									&& row_data.hasOwnProperty("parentid")
									&& row_data.hasOwnProperty("data")){
								rgrid.addChildNode(
									row_data.nodeid
									,row_data.parentid
									,row_data.data
								)
							}
						}
						
						// Check for update header of left pane
						if(update){
							if(data_respond.userdata
									&& !$.isEmptyObject(data_respond.userdata)){
								if((col_names = data_respond.userdata.colNames)
									&& $.isArray(col_names)){
									var count = col_names.length;
									while(count--){
										rgrid.jqGrid(
											"setLabel"
											,["column", count].join("_")
											,col_names[count]
										);
									}
								}
							}
						}
					}
				}
				
				,complete   : function(){
					var schedule_id = _view.__schedule_id
					, jobunit_id = _view.__jobunit_id
					;
					
					if((schedule_id === _.schedule_id) 
						&& (jobunit_id === _.jobunit_id)) {
						_.load_flg = false;
					}else{
						setTimeout(function(){
							_.reloadGrid();
						}, 1);
					}
				}
				
				,error   : __.loadDataError
			});
		}
		
		,/*
		 * Bind some action
		 */
		bindAction: function(){
			var _  = this
			,_btns = _.$btns
			;
			
			// Bind filter
			_btns.children("#filter").click(function(){
				// Verify role
				__.openCalendar(_, function(ldate){
					// Check ldate
					if(ldate && ((typeof ldate) == "number")
						&& (ldate != _.base_date)){
						// Update whenever base_date is changed
						// Renew base_date
						_.base_date = ldate;
						_.refreshGrids(true);
						_.setSpecifiedPeriod();
					}
				});
			});
			
			// Bind toggle left pane
			_btns.children("#toggle_view").click(function(){
				_.togglePane("east", this);
			});
		}
	});
	
	return view;
};