/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/


package com.necsoft.hinemos.webclient.jobmanagement.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.Date;

import org.jnp.interfaces.NamingContext;

import com.clustercontrol.CalendarNotFountException;
import com.clustercontrol.HinemosUnknownException;
import com.clustercontrol.JobMasterNotFoundException;
import com.clustercontrol.bean.CommonTableTreeItem;
import com.clustercontrol.jobmanagement.ejb.session.JobController;
import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.exception.HinemosWebRemoteException;
import com.necsoft.hinemos.webclient.jobmanagement.util.EjbConnectionManager;

/**
 * ジョブ[実行予定詳細]ビューの右側の実行予定マーク情報を取得するクライアント側アクションクラス<BR>
 * 
 * マネージャにSessionBean経由でアクセスし、実行予定詳細マーク情報を取得する
 * 
 */
public class GetRunScheduleDetail {
    // ----- instance メソッド ----- //
    // namingContextを定義
    private NamingContext m_namingContext = null;

    /**
     * namingContextを設定
     * 
     *@param namingContext
     *@return void
     */
    public void setNamingContext(NamingContext namingContext) {
        this.m_namingContext = namingContext;
    }

    /**
     * マネージャにSessionBean経由でアクセスし、<BR>
     * 実行予定詳細マーク情報を取得する
     * 
     * @param scheduleId
     *            スケジュールID
     * @param jobunitId
     *            所属ジョブユニットのジョブID
     * @param base
     *            表示基準日
     * @return 実行予定詳細マーク情報（Objectの2次元配列）
     * @throws HinemosWebException
     * 
     * @see com.clustercontrol.jobmanagement.ejb.session.JobController
     * @see com.clustercontrol.jobmanagement.util.EjbConnectionManager
     * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean
     *      #getRunScheduleDetail(java.lang.String, java.util.Date)
     */
    public CommonTableTreeItem get(String scheduleId, String jobunitId,
            Date base) throws HinemosWebException {
        EjbConnectionManager ejbConnectionManager = new EjbConnectionManager();
        ejbConnectionManager.setNamingContext(this.m_namingContext);
        JobController job = ejbConnectionManager.getJobController();

        CommonTableTreeItem item = null;
        try {
            item = job.getRunScheduleDetail(scheduleId, jobunitId, base);
        } catch (AccessException e) {
            // アクセス権なしの場合、エラーダイアログを表示する
            throw new HinemosWebAccessException(
                    "exception.job.runscheduledetail.access", e);
        } catch (RemoteException e) {
            throw new HinemosWebRemoteException("exception.job.runscheduledetail.remote", e);
        } catch (JobMasterNotFoundException e) {
            throw new HinemosWebException("exception.job.runscheduledetail.action", e);
        } catch (HinemosUnknownException e) {
            throw new HinemosWebException("exception.job.runscheduledetail.action", e);
        } catch (CalendarNotFountException e) {
            throw new HinemosWebException("exception.job.runscheduledetail.action", e);
        } 
        return item;
    }
}