/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.jobmanagement.servlet;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.clustercontrol.jobmanagement.bean.NodeDetailTableDefine;
import com.necsoft.hinemos.webclient.bean.TableColumnInfoJs;
import com.necsoft.hinemos.webclient.common.JsConstant;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.jobmanagement.business.GetNodeDetailTableDefineBusiness;
import com.necsoft.hinemos.webclient.json.CommonJson;
import com.necsoft.hinemos.webclient.json.GridHeaderJson;
import com.necsoft.hinemos.webclient.servlet.CommonServlet;
import com.necsoft.hinemos.webclient.util.ExceptionHandlerUtils;
import com.necsoft.hinemos.webclient.util.LogUtils;

/**
 * This class used for get header list
 * 
 * @version 1.0
 * @since 2011/12/14
 **/
public class GetNodeDetailTableDefineServlet extends CommonServlet {

    private static final long serialVersionUID = -6712416036223172058L;

    private static LogUtils logUtils = LogUtils
            .getLogUtils(GetNodeDetailTableDefineServlet.class);

    /**
     * Get header list
     * 
     * @param request
     *            : HttpServletRequest
     * @param response
     *            : HttpServletResponse
     * @throws ServletException
     * @throws IOException
     */
    public CommonJson process(HttpServletRequest request,
            HttpServletResponse response) throws ServletException, IOException {

        CommonJson result = new CommonJson();

        try {
            ArrayList<TableColumnInfoJs> tblDefine = doLoadTableDefine(request
                    .getLocale());

            setModelProperties(tblDefine);

            result = doConvertToJson(tblDefine);

        } catch (Exception ex) {
            logUtils.error(ex.getMessage(), ex.getCause());
            result = ExceptionHandlerUtils.doBuildCommonJson(
                    ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage());
        }
        return result;
    }

    /**
     * Get header list
     * 
     * @return ArrayList<TableColumnInfoJs>
     * @throws HinemosWebException
     */
    private ArrayList<TableColumnInfoJs> doLoadTableDefine(Locale locale)
            throws HinemosWebException {
        return new GetNodeDetailTableDefineBusiness()
                .getNodeDetailTableDefine(locale);
    }

    /**
     * @param tblDefine
     */
    private void setModelProperties(ArrayList<TableColumnInfoJs> tblDefine) {
        tblDefine.get(NodeDetailTableDefine.STATUS).setFormatter(
                JsConstant.GRID_FMATTER_RUN_STATUS);

        TableColumnInfoJs facilityName = tblDefine
                .get(NodeDetailTableDefine.FACILITY_NAME);
        facilityName.setFormatter(JsConstant.GRID_FMATTER_SCOPE_TYPE);
        Map<String, Object> scopeFmtOpt = new HashMap<String, Object>();
        scopeFmtOpt.put(JsConstant.GRID_FMATTER_SCOPE_TYPE_POSITION,
                NodeDetailTableDefine.FACILITY_ID);
        facilityName.setFormatoptions(scopeFmtOpt);

        tblDefine.get(NodeDetailTableDefine.START_RERUN_TIME).setFormatter(
                JsConstant.GRID_FMATTER_DATE_TIME);

        tblDefine.get(NodeDetailTableDefine.END_SUSPEND_TIME).setFormatter(
                JsConstant.GRID_FMATTER_DATE_TIME);

        tblDefine.get(NodeDetailTableDefine.MESSAGE).setFormatter(
                JsConstant.GRID_FMATTER_MSG_BTN);
    }

    /**
     * Convert data to JSON structure
     * 
     * @param tblDefine
     *            : ArrayList<TableColumnInfoJs>
     * @return GridHeaderJson
     */
    private GridHeaderJson doConvertToJson(
            ArrayList<TableColumnInfoJs> tblDefine) {
        GetNodeDetailTableDefineBusiness business = new GetNodeDetailTableDefineBusiness();
        return business.doConvertToJson(tblDefine);
    }

}