/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.monitor.servlet;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.jnp.interfaces.NamingContext;

import com.clustercontrol.bean.Property;
import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.exception.HinemosWebInvalidRequestParameterException;
import com.necsoft.hinemos.webclient.exception.HinemosWebRemoteException;
import com.necsoft.hinemos.webclient.json.CommonJson;
import com.necsoft.hinemos.webclient.json.GridDataJson;
import com.necsoft.hinemos.webclient.monitor.business.GetEventInfoPropertyBusiness;
import com.necsoft.hinemos.webclient.monitor.form.EventInfoPropertyForm;
import com.necsoft.hinemos.webclient.servlet.CommonServlet;
import com.necsoft.hinemos.webclient.util.ExceptionHandlerUtils;
import com.necsoft.hinemos.webclient.util.LogUtils;
import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;

/**
 * イベント情報データをリフレッシュするクラス
 * 
 * @version 1.0.0
 * @since 1.0.0
 **/
public class GetEventInfoPropertyServlet extends CommonServlet {
    private static final long serialVersionUID = -3131350422822624183L;

    private static LogUtils logUtils = LogUtils
            .getLogUtils(GetEventInfoPropertyServlet.class);

    public CommonJson process(HttpServletRequest request,
            HttpServletResponse response) throws ServletException, IOException,
            HinemosWebAccessException {

        CommonJson result = new CommonJson();

        try {
            // NammingContextを取得する
            NamingContext namingContext = doLoadNamingContext(request);

            // 中間変数を宣言
            Property propertyEvent = doLoadProperty(request, namingContext);

            // Create JSON
            result = doConvertToJson(propertyEvent, request.getLocale()
                    .getLanguage());

        } catch (HinemosWebAccessException ex) {
            logUtils.info(ex.getMessage());
            throw new HinemosWebAccessException();
        } catch (HinemosWebRemoteException ex) {
            logUtils.error(ex.getMessage(), ex.getCause());
            result = ExceptionHandlerUtils.doBuildCommonJson(
                    ExceptionHandlerUtils.LEVEL_WARNING, ex.getMessage());

        } catch (Exception ex) {
            logUtils.error(ex.getMessage(), ex.getCause());
            result = ExceptionHandlerUtils.doBuildCommonJson(
                    ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage());
        }
        return result;
    }

    private Property doLoadProperty(HttpServletRequest request,
            NamingContext namingContext) throws HinemosWebException {
        // 中間変数を宣言
        Property propertyEvent = null;
        EventInfoPropertyForm form = new EventInfoPropertyForm();
        PopulateBeanUtils.populateBean(form, request);
        if (!isValidRequestParam(form)) {
            throw new HinemosWebInvalidRequestParameterException(
                    "exception.monitor.event.info.param");
        }
        GetEventInfoPropertyBusiness business = new GetEventInfoPropertyBusiness();
        propertyEvent = business.getEventInfoProperty(form, namingContext,
                request.getLocale());
        return propertyEvent;
    }

    private GridDataJson doConvertToJson(Property propertyEvent, String lang) {
        GetEventInfoPropertyBusiness business = new GetEventInfoPropertyBusiness();
        return business.doConvertToJson(propertyEvent, lang);
    }

    private boolean isValidRequestParam(EventInfoPropertyForm form) {
        boolean isValid = true;
        if (form.getMonitorId() == null
                || "".equalsIgnoreCase(form.getMonitorId().trim())
                || form.getPluginId() == null
                || "".equalsIgnoreCase(form.getPluginId().trim())
                || form.getFacilityId() == null
                || "".equalsIgnoreCase(form.getFacilityId().trim())
                || form.getReceiveTime() == 0) {
            isValid = false;
        }
        return isValid;
    }
}