/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.repository.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.Locale;

import org.jnp.interfaces.NamingContext;

import com.clustercontrol.FacilityNotFoundException;
import com.clustercontrol.bean.Property;
import com.clustercontrol.repository.bean.NodeInfo;
import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.exception.HinemosWebFacilityNotFoundException;
import com.necsoft.hinemos.webclient.exception.HinemosWebRemoteException;
import com.necsoft.hinemos.webclient.repository.util.EjbConnectionManager;
import com.necsoft.hinemos.webclient.repository.util.NodePropertyUtil;

/**
 * ノード属性情報を取得するクライアント側アクションクラス<BR>
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class GetNodeProperty {

    // ----- コンストラクタ ----- //

    // ----- instance メソッド ----- //
    // namingContextを定義
    private NamingContext m_namingContext = null;

    /**
     * namingContextを設定
     * 
     * @param namingContext
     * @return void
     */
    public void setNamingContext(NamingContext namingContext) {
        this.m_namingContext = namingContext;
    }

    /**
     * ノード属性情報を取得します。
     * 
     * @param facilityId
     * @param property
     * @return ノード属性情報
     * @throws HinemosWebException
     */
    public Property getProperty(String facilityId, int mode, Locale locale)
            throws HinemosWebException {

        EjbConnectionManager ejbConnectionManager = new EjbConnectionManager();
        ejbConnectionManager.setNamingContext(this.m_namingContext);
        RepositoryController repository = ejbConnectionManager
                .getRepositoryController();

        Property property = null;
        try {
            NodeInfo nodeInfo = repository.getNode(facilityId);

            property = NodePropertyUtil.node2property(nodeInfo, mode, locale,
                    m_namingContext);
        } catch (AccessException e) {
            throw new HinemosWebAccessException(
                    "exception.repository.property.access", e);
        } catch (RemoteException e) {
            throw new HinemosWebRemoteException(
                    "exception.repository.property.remote", e);
        } catch (FacilityNotFoundException e) {
            // 指定のファシリティがマネージャに存在しない。
            // 何も表示しない。
            throw new HinemosWebFacilityNotFoundException(
                    "exception.repository.property.facility", e);
        }
        return property;
    }
}